<?php

namespace Tygh\Addons\ReportsExtends\Documents\Reports;

use Tygh\Database\Connection;
use Tygh\Exceptions\InputException;
use Tygh\Template\Document\Document;
use Tygh\Template\Document\IIncludableType;
use Tygh\Template\Document\IPreviewableType;
use Tygh\Template\Document\IType;
use Tygh\Template\Document\Repository;
use Tygh\Template\ITemplate;
use Tygh\Template\Renderer;
use Tygh\Template\VariableCollectionFactory;


class Type implements IType, IPreviewableType, IIncludableType
{
    const DOCUMENT_TYPE = 'reports_extends';

    /** @var Repository */
    protected $repository;

    /** @var VariableCollectionFactory */
    protected $collection_factory;

    /** @var Connection */
    protected $connection;

    /** @var Renderer */
    protected $renderer;

    public function __construct(
        Repository $repository,
        Connection $connection,
        Renderer $renderer,
        VariableCollectionFactory $collection_factory
    )
    {
        $this->connection = $connection;
        $this->renderer = $renderer;
        $this->repository = $repository;
        $this->collection_factory = $collection_factory;
    }

    public function preview(Document $document)
    {
        $condition = fn_get_table_condition('?:report.table_id');
        $report_id = (int) $this->connection->getField('SELECT MIN(report_id) FROM ?:report WHERE 1 ?p', $condition);

        if (empty($report_id)) {
            throw new InputException(__("document_preview_gift_certificate_not_found"));
        }

        $data = fn_get_order_reports($report_id);

        return $this->render($data, $document, DESCR_SL);
    }

    public function includeDocument($code, $lang_code, $params)
    {
        $report_id = (int) array_shift($params);

        return $this->renderById($report_id, $code, $lang_code);
    }

    public function getCode()
    {
        return self::DOCUMENT_TYPE;
    }

    public function renderByData($report, $code = 'default', $lang_code)
    {
        $document = $this->repository->findByTypeAndCode($this->getCode(), $code);

        if (!$document && $code != 'default') {
            $document = $this->repository->findByTypeAndCode($this->getCode(), 'default');
        }

        if ($document) {
            return $this->render($report, $document, $lang_code);
        }

        return '';
    }

    public function renderById($report_id, $code = 'default', $lang_code)
    {
        $data = fn_get_order_reports($report_id);


        if ($data) {
            return $this->renderByData($data, $code, $lang_code);
        }

        return '';
    }
    
    public function render($report, ITemplate $document, $lang_code)
    {
        $context = new Context($report, $lang_code);
        $variable_collection = $this->collection_factory->createCollection(self::SCHEMA_DIR, $this->getCode(), $context);

        return $this->renderer->renderTemplate($document, $context, $variable_collection);
    }
}