<?php

use Tygh\Enum\SiteArea;
use Tygh\Registry;
use Tygh\Tygh;

function fn_print_reports($report_ids, $params = [])
{
    // Backward compatibility
    if (is_bool($params)) {
        // phpcs:ignore PHPCompatibility.FunctionUse.ArgumentFunctionsReportCurrentValue.NeedsInspection
        $args = func_get_args();
        $params = [];

        fn_set_hook('print_reports_normalize_parameters', $args, $params);

        if (isset($args[2])) {
            $params['area'] = $args[2];
        }
        if (isset($args[3])) {
            $params['lang_code'] = $args[3];
        }
    }

    // Default params
    $params = array_merge(
        [
            'area'               => AREA,
            'lang_code'          => CART_LANGUAGE,
            'html_wrap'          => true,
            'add_page_break'     => true,
        ],
        $params
    );

    $report_ids = (array) $report_ids;

    fn_set_hook('print_reports_pre', $report_ids, $params);

    $html = [];
    $data = [];

    // На data можно вызвать данные через модуль
    $data['profile_fields'] = fn_get_profile_fields('I', [], $params['lang_code']);

    foreach ($report_ids as $report_id) {
        if (Registry::get('settings.Appearance.email_templates') === 'old') {
            $report = fn_get_order_reports($report_id, $params['lang_code']);
            if (empty($report)) {
                continue;
            }
            // Нужно вызвать массив
        
            //

            if (fn_allowed_for('MULTIVENDOR') && SiteArea::isStorefront($params['area'])) {
                $data['company_data'] = fn_filter_company_data_by_profile_fields(
                    fn_get_company_placement_info($report['company_id'], $params['lang_code']),
                    [
                        'field_prefix' => 'company_',
                    ]
                );
            } else {
                $data['company_data'] = fn_get_company_placement_info($report['company_id'], $params['lang_code']);
            }

            /** @var \Tygh\SmartyEngine\Core $view */
            $view = Tygh::$app['view'];
            foreach ($data as $key => $value) {
                $view->assign($key, $value);
            }

            $template = $params['html_wrap'] ? 'addons/reports_extends/print_reports.tpl' : 'addons/reports_extends/reports.tpl';
            $html[] = $view->displayMail(
                $template,
                false,
                $params['area'],
                $report['company_id'],
                $params['lang_code']
            );
        } else {
            /** @var \Tygh\Template\Document\Order\Type $document_type */
            $document_type = Tygh::$app['template.document.reports_extends.type'];
            $template_code = isset($params['template_code']) ? $params['template_code'] : 'default';
            $template = $document_type->renderById($report_id, $template_code, $params['lang_code'], $params['area']);

            if ($params['html_wrap']) {
                /** @var \Tygh\SmartyEngine\Core $view */
                $view = Tygh::$app['view'];
                $view->assign('content', $template);
                $template = $view->displayMail('common/wrap_document.tpl', false, 'A');
            }

            $html[] = $template;
        }

        if (
            !$params['add_page_break']
            || $report_id === end($report_ids)
        ) {
            continue;
        }

        $html[] = "<div style='page-break-before: always;'>&nbsp;</div>";
    }

    $output = implode(PHP_EOL, $html);

    fn_set_hook('print_order_invoices_post', $report_ids, $params, $html, $output);

    return $output;
}
